Struct gio_sys::GMountMountFlags
[−]
#[repr(C)]pub struct GMountMountFlags { /* fields omitted */ }
Methods
impl GMountMountFlags
fn empty() -> GMountMountFlags
Returns an empty set of flags.
fn all() -> GMountMountFlags
Returns the set containing all flags.
fn bits(&self) -> c_uint
Returns the raw value of the flags currently stored.
fn from_bits(bits: c_uint) -> Option<GMountMountFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: c_uint) -> GMountMountFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: GMountMountFlags) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: GMountMountFlags) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: GMountMountFlags)
Inserts the specified flags in-place.
fn remove(&mut self, other: GMountMountFlags)
Removes the specified flags in-place.
fn toggle(&mut self, other: GMountMountFlags)
Toggles the specified flags in-place.